function ret = accelerationDueToPushBeam(this, PositionVector, VelocityVector)
    % is the distance between the chamber center and the cross point of push beam and z-axis (along the gravity)
    WaveVectorEndPoint = [0, 1, this.DistanceBetweenPushBeamAnd3DMOTCenter/this.PushBeamDistance];
    WaveVectorEndPoint = WaveVectorEndPoint./norm(WaveVectorEndPoint);
    Origin=[0,0,0];

    SaturationIntensity = this.calculateLocalSaturationIntensity(this.PushBeamSaturationParameter, PositionVector, Origin, WaveVectorEndPoint, this.PushBeamRadius, this.PushBeamWaist);
    
    DopplerShift = dot(WaveVectorEndPoint(:), VelocityVector) * this.PushBeamWaveNumber;
    
    Detuning = this.PushBeamDetuning - DopplerShift;
    
    s_push = SaturationIntensity/(1 + SaturationIntensity + (4 * (Detuning./this.PushBeamLinewidth).^2));
    a_sat  = (Helper.PhysicsConstants.PlanckConstantReduced * this.PushBeamWaveNumber * WaveVectorEndPoint(:)/Helper.PhysicsConstants.Dy164Mass).*(this.PushBeamLinewidth * 0.5);
    a_push = a_sat .* (s_push/(1+s_push));
             
    if this.SpontaneousEmission
        a_scatter = this.accelerationDueToSpontaneousEmissionProcess(s_push, s_push, this.PushBeamLinewidth, this.PushBeamWaveNumber);
    else
        a_scatter = [0,0,0];
    end

    a_total = a_push + a_scatter;
    
    ret = a_total(1:3);
end

